# LEECHCRAFT_INCLUDE_DIR
# LEECHCRAFT_LIBRARIES
# LEECHCRAFT_FOUND

set (CMAKE_INCLUDE_CURRENT_DIR ON)
find_package (Qt5Widgets)

find_package (Qt5LinguistTools REQUIRED)

macro (QtWrapUi outfiles)
	set (UIS_H)
    QT5_WRAP_UI (UIS_H ${ARGN})
	set (${outfiles} ${${outfiles}} ${UIS_H})
endmacro ()

macro (QtAddResources outfiles)
	set (RCCS)
	QT5_ADD_RESOURCES (RCCS ${ARGN} OPTIONS -compress-algo best -threshold 0)
	set (${outfiles} ${${outfiles}} ${RCCS})
endmacro ()

macro (FindQtLibs Target)
	cmake_policy (SET CMP0043 NEW)
	set (CMAKE_INCLUDE_CURRENT_DIR ON)
	find_package (Qt5 COMPONENTS ${ARGN})
	set (_TARGET_LINK_QT5_LIBS "")
	foreach (V ${ARGN})
		list (APPEND _TARGET_LINK_QT5_LIBS "Qt5::${V}")
	endforeach ()
	target_link_libraries (${Target} ${_TARGET_LINK_QT5_LIBS})
endmacro ()

find_path(LEECHCRAFT_INCLUDE_DIR NAMES leechcraft/config.h PATH ENV)
if (LEECHCRAFT_INCLUDE_DIR)
	set (LEECHCRAFT_INCLUDE_DIR "${LEECHCRAFT_INCLUDE_DIR}/leechcraft")
endif ()

find_library(_LEECHCRAFT_UTIL NAMES leechcraft-util-qt5)
find_library(_LEECHCRAFT_UTIL_DB NAMES leechcraft-util-db-qt5)
find_library(_LEECHCRAFT_UTIL_GUI NAMES leechcraft-util-gui-qt5)
find_library(_LEECHCRAFT_UTIL_MODELS NAMES leechcraft-util-models-qt5)
find_library(_LEECHCRAFT_UTIL_NETWORK NAMES leechcraft-util-network-qt5)
find_library(_LEECHCRAFT_UTIL_QML NAMES leechcraft-util-qml-qt5)
find_library(_LEECHCRAFT_UTIL_SHORTCUTS NAMES leechcraft-util-shortcuts-qt5)
find_library(_LEECHCRAFT_UTIL_SLL NAMES leechcraft-util-sll-qt5)
find_library(_LEECHCRAFT_UTIL_SVCAUTH NAMES leechcraft-util-svcauth-qt5)
find_library(_LEECHCRAFT_UTIL_SYS NAMES leechcraft-util-sys-qt5)
find_library(_LEECHCRAFT_UTIL_TAGS NAMES leechcraft-util-tags-qt5)
find_library(_LEECHCRAFT_UTIL_THREADS NAMES leechcraft-util-threads-qt5)
find_library(_LEECHCRAFT_UTIL_XDG NAMES leechcraft-util-xdg-qt5)
find_library(_LEECHCRAFT_UTIL_XPC NAMES leechcraft-util-xpc-qt5)
find_library(_LEECHCRAFT_UTIL_XSD NAMES leechcraft-util-xsd-qt5)

find_library(_LEECHCRAFT_UTIL_X11_OPT NAMES leechcraft-util-x11-qt5)
set (_LEECHCRAFT_UTIL_X11)
if (_LEECHCRAFT_UTIL_X11_OPT)
	set (_LEECHCRAFT_UTIL_X11 "${_LEECHCRAFT_UTIL_X11_OPT}")
endif ()

find_library(_LEECHCRAFT_XSD NAMES leechcraft-xsd-qt5)
set (LEECHCRAFT_LIBRARIES
	${_LEECHCRAFT_UTIL}
	${_LEECHCRAFT_UTIL_DB}
	${_LEECHCRAFT_UTIL_GUI}
	${_LEECHCRAFT_UTIL_MODELS}
	${_LEECHCRAFT_UTIL_NETWORK}
	${_LEECHCRAFT_UTIL_QML}
	${_LEECHCRAFT_UTIL_SHORTCUTS}
	${_LEECHCRAFT_UTIL_SLL}
	${_LEECHCRAFT_UTIL_SVCAUTH}
	${_LEECHCRAFT_UTIL_SYS}
	${_LEECHCRAFT_UTIL_TAGS}
	${_LEECHCRAFT_UTIL_THREADS}
	${_LEECHCRAFT_UTIL_X11}
	${_LEECHCRAFT_UTIL_XDG}
	${_LEECHCRAFT_UTIL_XPC}
	${_LEECHCRAFT_UTIL_XSD}
	${_LEECHCRAFT_XSD})
set (LEECHCRAFT_USE_FILE "${CMAKE_MODULE_PATH}/UseLeechCraft.cmake")

if(LEECHCRAFT_INCLUDE_DIR AND _LEECHCRAFT_UTIL AND _LEECHCRAFT_XSD)
	set(LEECHCRAFT_FOUND 1)
endif()

if(LEECHCRAFT_FOUND)
	message(STATUS "Found LeechCraft libraries at ${LEECHCRAFT_LIBRARIES}")
	message(STATUS "Found LeechCraft headers at ${LEECHCRAFT_INCLUDE_DIR}")
else()
	if(LEECHCRAFT_FIND_REQUIRED)
		message(FATAL_ERROR "Could NOT find required LeechCraft library, aborting")
	else()
		message(STATUS "Could NOT find LeechCraft")
	endif()
endif()

set (CMAKE_AUTOMOC TRUE)
set (CMAKE_CXX_STANDARD 17)
set (CMAKE_CXX_STANDARD_REQUIRED TRUE)
set (CMAKE_CXX_EXTENSIONS OFF)

set (LC_BINDIR bin)
set (LC_PLUGINS_DEST lib64/leechcraft/plugins-qt5)
set (LC_TRANSLATIONS_DEST share/leechcraft/translations)
set (LC_SETTINGS_DEST share/leechcraft/settings)
set (LC_SHARE_DEST share/leechcraft)

set (CMAKE_CXX_FLAGS "-O2 -Wall -U_FORTIFY_SOURCE -D_FORTIFY_SOURCE=3 -fstack-protector-strong -funwind-tables -fasynchronous-unwind-tables -fstack-clash-protection -Werror=return-type -flto=auto -g -Doverride= -I/usr/include/gstreamer-1.0 -I/usr/include/glib-2.0 -I/usr/lib64/glib-2.0/include -pthread -fvisibility=hidden -Wall -Wextra -DQT_DEPRECATED_WARNINGS -DQT_DISABLE_DEPRECATED_BEFORE='QT_VERSION_CHECK(5,8,0)'")
set (CMAKE_SHARED_LINKER_FLAGS " -Wl,--as-needed")
set (CMAKE_EXE_LINKER_FLAGS " -Wl,--as-needed")
